# A library to deal with Daisy 2.02 digital talking books

## Installation

You can install `daisy-dtb` with all common python dependancies manager.

* With pip : ```pip install daisy-dtb```
* With uv : ```uv add daisy-dtb```


## References

* [Daisy 2.02 specifications](https://daisy.org/activities/standards/daisy/daisy-2/daisy-format-2-02-specification/)